package db

import "time"

type Message struct {
	ID      int       `db:"id"      json:"tohleJeID"` // comment
	Channel string    `db:"channel"`                  // jiny comment
	Text    string    `db:"text"`
	Created time.Time `db:"created"`
}

// GetMessage returns message loaded from DB
func (d *DB) GetMessage(id int) (msg Message, err error) {
	row := d.db.QueryRow("SELECT id, channel, text, created FROM messages WHERE ID = ?", id)
	err = row.Scan(&msg.ID, &msg.Channel, &msg.Text, &msg.Created)
	return
}

// GetAllMessages returns all messages from channel
func (d *DB) GetAllMessages(channel string) (messages []Message, err error) {
	rows, err := d.db.Query("SELECT id, channel, text, created FROM messages WHERE channel = ?", channel)
	if err != nil {
		return nil, err
	}
	for rows.Next() {
		var msg Message
		if err := rows.Scan(&msg.ID, &msg.Channel, &msg.Text, &msg.Created); err != nil {
			return nil, err
		}
		messages = append(messages, msg)
	}
	return messages, rows.Err()
}

// SaveMessage insert the message with current time into DB
func (d *DB) SaveMessage(channel, text string) error {
	_, err := d.db.Exec(
		"INSERT INTO messages (channel, text, created) VALUES (?, ?, ?)",
		channel, text, time.Now(),
	)
	return err
}

// DeleteMessage removed message with given ID
func (d *DB) DeleteMessage(id int) error {
	_, err := d.db.Exec("DELETE FROM messages WHERE id = ?", id)
	return err
}
