package main

import (
	"io/ioutil"
	"net/http"
)

// Server is a simple handy HTTP server
type Server struct {
	memory map[string][]byte
}

// Start the webserver on given address
func (s *Server) Start(listen string) error {
	http.HandleFunc("/api/list", s.listHandler)
	http.HandleFunc("/api/get", s.getHandler)
	http.HandleFunc("/api/set", s.setHandler)

	return http.ListenAndServe(listen, http.DefaultServeMux)
}

func (s *Server) listHandler(w http.ResponseWriter, r *http.Request) {
	for key := range s.memory {
		w.Write([]byte(key))
	}
}

func (s *Server) getHandler(w http.ResponseWriter, r *http.Request) {
	if r.Method != http.MethodGet {
		http.Error(w, "405 Takhle prosim ne", http.StatusMethodNotAllowed)
		return
	}

	key := r.URL.Query().Get("key")
	value, found := s.memory[key]
	if !found {
		http.Error(w, "404 Neexistuje", http.StatusNotFound)
	} else {
		w.Write(value)
	}
}

func (s *Server) setHandler(w http.ResponseWriter, r *http.Request) {
	if r.Method != http.MethodPost {
		http.Error(w, "405 Takhle prosim ne", http.StatusMethodNotAllowed)
		return
	}

	if key := r.URL.Query().Get("key"); key == "" {
		http.Error(w, "400 Nenene!!!", http.StatusBadRequest)
	} else {
		body, _ := ioutil.ReadAll(r.Body)
		s.memory[key] = body
	}
}
